@@ -4,6 +4,7 @@ from gcgen.decorators import snippet, generator
 from gcgen.api.snippets_helpers import get_snippet, SnippetFn
 from gcgen.api.write_file import write_file
 from gcgen.api.types import Json
+from gcgen.api.tree import *
 
 
 __all__ = [
@@ -15,4 +16,10 @@ __all__ = [
     "get_snippet",
     "write_file",
     "Json",
+    "TreeOp",
+    "on_visit",
+    "on_transform",
+    "NodeVisitor",
+    "NodeTransformer",
+    "parse_tree",
 ]
